@@ -565,6 +565,7 @@ class Session(Fixture):
 # The URL Helper
 #########################################################################################
 
+
 def URL(
     *parts,
     vars=None,
@@ -1057,7 +1058,7 @@ class Reloader:
             func = route.callback
             rule = route.rule
             # remove optional trailing / from rule
-            if rule.endswith('<:re:/?>'):
+            if rule.endswith("<:re:/?>"):
                 rule = rule[:-8]
             routes.append(
                 {
@@ -1070,6 +1071,7 @@ class Reloader:
         Reloader.ROUTES = sorted(routes, key=lambda item: item["rule"])
         ICECUBE.update(threadsafevariable.ThreadSafeVariable.freeze())
 
+
 #########################################################################################
 # Web Server and Reload Logic: Error Handling
 #########################################################################################
@@ -1157,7 +1159,7 @@ def try_app_watch_tasks():
             del APP_WATCH["tasks"][handler]
 
 
-def watch(apps_folder, server="default", mode="sync"):
+def watch(apps_folder, server_config, mode="sync"):
     def watch_folder_event_loop(apps_folder):
         loop = asyncio.new_event_loop()
         asyncio.set_event_loop(loop)
@@ -1190,18 +1192,21 @@ def watch(apps_folder, server="default", mode="sync"):
             if not mode == "lazy":
                 try_app_watch_tasks()
 
-    if server == "default":
+    if server_config == "windows":
         # default wsgi server block the main thread so we open a new thread for the file watcher
         threading.Thread(
             target=watch_folder_event_loop, args=(apps_folder,), daemon=True
         ).start()
-    elif server == "tornado":
+    elif server_config == "tornado":
         # tornado delegate to asyncio so we add a future into the event loop
         asyncio.ensure_future(watch_folder(apps_folder))
-    elif server == "gunicorn":
+    elif server_config == "gunicorn+gevent":
         # supposedly number_workers > 1
         click.echo("--watch option has no effect in multi-process environment \n")
         return
+    else:
+        # should never happen
+        return
 
     if mode == "lazy":
         Reloader.install_reloader_hook()
@@ -1210,38 +1215,34 @@ def watch(apps_folder, server="default", mode="sync"):
 def start_server(args):
     host, port, apps_folder = args["host"], int(args["port"]), args["apps_folder"]
     number_workers = args["number_workers"]
-
-    server = None  # need for watcher
-    run = lambda: 0  # main run
+    server = None
+    params = dict(server="gevent", host=host, port=port, reloader=False,)
+    if args["ssl_cert"] is not None:
+        params["certfile"] = args["ssl_cert"]
+        params["keyfile"] = args["ssl_key"]
     if platform.system().lower() == "windows":
-        # Tornado fail on windows
-        server = "default"
-        run = lambda: bottle.run(host=host, port=int(port), reloader=False)
+        if not gevent:
+            logging.error("gevent not installed")
+            return
+        server_config = "windows"
+        params["server"] = "gevent"
     elif number_workers < 1:
-        server = "tornado"
-        run = lambda: bottle.run(server="tornado", host=host, port=port, reloader=False)
+        server_config = "tornado"
+        params["server"] = "tornado"
     else:
         if not gunicorn:
             logging.error("gunicorn not installed")
-        elif not gevent:
+            return
+        if not gevent:
             logging.error("gevent not installed")
-        else:
-            server = "gunicorn"
-            sys.argv[:] = sys.argv[:1]  # else break gunicorn
-            run = lambda: bottle.run(
-                server="gunicorn",
-                host=host,
-                port=port,
-                workers=number_workers,
-                worker_class="gevent",
-                reloader=False,
-                certfile=args["ssl_cert"],
-                keyfile=args["ssl_key"],
-            )
+            return
+        server_config = "gunicorn+gevent"
+        params.update(server="gunicorn", workers=number_workers, worker_class="gevent")
+        sys.argv[:] = sys.argv[:1]  # else break gunicorn
 
     if args["watch"] != "off":
-        watch(apps_folder, server, args["watch"])
-    run()
+        watch(apps_folder, server_config, args["watch"])
+    bottle.run(**params)
 
 
 def check_compatible(version):
@@ -1307,7 +1308,6 @@ def install_args(args, reinstall_apps=False):
         with open(session_secret_filename, "w") as fp:
             fp.write(str(uuid.uuid4()))
 
-    session_secret_filename = os.path.join(args["service_folder"], "session.secret")
     with open(session_secret_filename) as fp:
         Session.SECRET = fp.read()
 
