@@ -18,6 +18,9 @@ DB_POOL_SIZE = 1
 DB_MIGRATE = True
 DB_FAKE_MIGRATE = False  # maybe?
 
+# location where to store uploaded files:
+UPLOAD_PATH = os.path.join(APP_FOLDER, "uploads")
+
 # send email on regstration
 VERIFY_EMAIL = False
 
